reticulate is a hard dependency of nat.python, so this really
just checks that a usable Python is set up, guiding the user to
simple_python() when it is not. The name is kept for continuity with the
ecosystem's check_reticulate() entry point.
reticulate is a hard dependency of nat.python, so this really
just checks that a usable Python is set up, guiding the user to
simple_python() when it is not. The name is kept for continuity with the
ecosystem's check_reticulate() entry point.